==> jena-5.3.0-source-release.zip: jena-5.3.0/jena-arq/src/test/java/org/apache/jena/sparql/engine/join/TS_Join.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.jena.sparql.engine.join;

import org.junit.runner.RunWith ;
import org.junit.runners.Suite ;
import org.junit.runners.Suite.SuiteClasses ;

@RunWith(Suite.class)
@SuiteClasses( {
    TestJoinSimple.class
    , TestJoinNestedLoopSimple.class    // Real simple materializing version.
    , TestJoinNestedLoop.class
    , TestHashJoin.class

    , TestLeftJoinSimple.class
    , TestLeftJoinNestedLoopSimple.class    // Real simple materializing version.
    , TestLeftJoinNestedLoop.class
    , TestHashLeftJoin_Left.class           // Left hash, stream right
    , TestHashLeftJoin_Right.class          // Normal implementation.
    , TestTableJoin.class
})

public class TS_Join { }

==> jena-6.0.0-source-release.zip: jena-6.0.0/jena-arq/src/test/java/org/apache/jena/sparql/engine/join/TS_Join.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 *   SPDX-License-Identifier: Apache-2.0
 */

package org.apache.jena.sparql.engine.join;

import org.junit.platform.suite.api.SelectClasses;
import org.junit.platform.suite.api.Suite;

@Suite
@SelectClasses({
    TestJoinSimple.class
    , TestJoinNestedLoopSimple.class    // Real simple materializing version.
    , TestJoinNestedLoop.class
    , TestHashJoin.class

    , TestLeftJoinSimple.class
    , TestLeftJoinNestedLoopSimple.class    // Real simple materializing version.
    , TestLeftJoinNestedLoop.class
    , TestHashLeftJoin_Left.class           // Left hash, stream right
    , TestHashLeftJoin_Right.class          // Normal implementation.
    , TestTableJoin.class
})

public class TS_Join { }
